SqlCipherOpenDatabaseOptions class abstract
Options for opening the database see openDatabase for details
- Inheritance
-
- Object
- OpenDatabaseOptions
- SqlCipherOpenDatabaseOptions
Constructors
- SqlCipherOpenDatabaseOptions({int? version, OnDatabaseConfigureFn? onConfigure, OnDatabaseCreateFn? onCreate, OnDatabaseVersionChangeFn? onUpgrade, OnDatabaseVersionChangeFn? onDowngrade, OnDatabaseOpenFn? onOpen, String? password, bool readOnly = false, bool singleInstance = true})
-
Open the database at a given path
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onConfigure → OnDatabaseConfigureFn?
-
called right after opening the database.
no setterinherited
- onCreate → OnDatabaseCreateFn?
-
Called when the database is created.
no setterinherited
- onDowngrade → OnDatabaseVersionChangeFn?
-
Called when the database is downgraded.
no setterinherited
- onOpen → OnDatabaseOpenFn?
-
Called after all other callbacks have been called.
no setterinherited
- onUpgrade → OnDatabaseVersionChangeFn?
-
Called when the database is upgraded.
no setterinherited
- password ↔ String?
-
Password for encrypted database.
getter/setter pair
- readOnly → bool
-
Open the database in read-only mode (no callback called).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleInstance → bool
-
The existing single-instance (hot-restart)
no setterinherited
- version → int?
-
Specify the expected version.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited